using Telerik.UI.Xaml.Controls.DataVisualization;
using Windows.Foundation;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Shapes;

namespace SampleApp
{
    /// <summary>
    /// This class represents and indicator in the form of an arrow with a circular tail.
    /// </summary>
    [TemplatePart(Name = "PART_Path", Type = typeof(Path))]
    [TemplatePart(Name = "PART_Layout", Type = typeof(Grid))]
    [TemplatePart(Name = "PART_NeedleRotateTransform", Type = typeof(RotateTransform))]
    public class CustomArrowIndicator : NeedleGaugeIndicator
    {
        private Panel layout;
        private Path path;

        /// <summary>
        /// Initializes a new instance of the ArrowGaugeIndicator class.
        /// </summary>
        public CustomArrowIndicator()
        {
            this.DefaultStyleKey = typeof(CustomArrowIndicator);
        }

        /// <summary>
        /// Initializes the template parts of the control (see the TemplatePart attributes for more information).
        /// </summary>
        protected override bool ApplyTemplateCore()
        {
            bool applied = base.ApplyTemplateCore();

            this.layout = this.GetTemplateChild("PART_Layout") as Panel;
            applied = applied && this.layout != null;

            this.path = this.GetTemplateChild("PART_Path") as Path;
            applied = applied && this.path != null;

            return applied;
        }

        /// <summary>
        /// Called in the arrange pass of the layout system.
        /// </summary>
        /// <param name="finalSize">The final size that was given by the layout system.</param>
        /// <returns>The final size of the panel.</returns>
        protected override Size ArrangeOverride(Size finalSize)
        {
            this.UpdateArrow(finalSize);
            return base.ArrangeOverride(finalSize);
        }

        private void UpdateArrow(Size size)
        {
            // Fine tune the position and the size of the indicator here
            this.path.Height = 0.05 * this.Radius;
            this.path.Width = this.Radius * this.RadiusScale;

            var right = 0.5 * size.Width;
            this.path.Margin = new Thickness(0, 0, right, 0);
        }
    }
}